View source: R/MappingFunctions.R
| PerCapitaMap_leaflet | R Documentation |
Creates an interactive Leaflet map displaying active cases per 'people' for the input data.
PerCapitaMap_leaflet(DATA, people = 1e+05, boundaryweights = 0.05)
DATA |
Data containing prevalence information to map. |
people |
Transform from proportion of population to per 'people'. |
boundaryweights |
Weight assigned to the maps boundary edges. |
Outputs an interactive leaflet map displaying active cases per 'people' for the input data.
Other mapplots:
EventMap_leaflet(),
EventMap_tmap(),
PerCapitaMap_tmap()
## Not run:
Denmark <- LoadData("LoadDenmark")
PerCapitaMap_leaflet(Denmark)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.