View source: R/geomUpdateUtils.R
| remGeoSurplus | R Documentation |
Some geography files are collections of many countries that overlap with other files that have their own higher-quality data. The remGeoSurplus function ensures each country is only present once in the dataset.
remGeoSurplus(
input_file,
collection_files = c("geomEurope", "geomSmallCountries")
)
input_file |
In file |
collection_files |
File(s) with geoms to remove |
input_file Updated input file
## Not run:
data("geomGlobal")
localcovid19now:::remGeoSurplus(geomGlobal)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.